<?php

/*
=====================================================
 Extension: Comment Text Format
-----------------------------------------------------
 Author: Yvonne
 Version: 1.2.0
=====================================================
 File: ext.comment_text_format.php
-----------------------------------------------------
 Purpose: This extension applies a custom text 
 format to comments.
=====================================================
*/

if ( ! defined('EXT'))
{
    exit('Invalid file request');
}

class Comment_text_format
{
	var $settings		= array();
	
	var $name			= 'Comment Text Format';
	var $version		= '1.2.0';
	var $description	= 'Text formatting for comments';
	var $settings_exist	= 'y';
	var $docs_url		= 'http://www.ennovy.org/weblog/comments/comment-text-formatting-extension/';

	// -------------------------------
	//   Constructor - Extensions use this for settings
	// -------------------------------

	function Comment_text_format($settings='')
	{
		global $LANG;
		$LANG->fetch_language_file('comment_text_format');
		$this->name = $LANG->line('comment_text_format_name');
		$this->description = $LANG->line('comment_text_format_description');
		$this->settings = $settings;
	}
	// END

	// -----------------------------
	//	 Add formatting to comments 
	// -----------------------------	
	
	function add_formatting($row)
	{
		global $TMPL, $EXT;
		
		$comment_format = !$TMPL->fetch_param('format') ? '' : $TMPL->fetch_param('format');
		
		if ($comment_format != '')
		{
			$format = $comment_format;
		}
		elseif ($this->settings['apply_all'] == 'yes')
		{
			$format = $this->settings['format'];		
		}
		else
		{
			$weblog_ids = explode('|', trim($this->settings['weblog_ids']));
			
			if (in_array($row['weblog_id'], $weblog_ids))
			{
				$format = $this->settings['format'];		
			}
			else
			{
				$format = $row['comment_text_formatting'];
			}
		}
		
		if ( ! class_exists('Typography'))
		{
			require PATH_CORE.'core.typography'.EXT;
		}
                
		$TYPE = new Typography(0);
		
		$comment = $EXT->last_call!=false ? $EXT->last_call : '';
		$comment .= $TYPE->parse_type( $row['comment'], 
				array(
					'text_format'   => $format,
					'html_format'   => $row['comment_html_formatting'],
					'auto_links'    => $row['comment_auto_link_urls'],
					'allow_img_url' => $row['comment_allow_img_urls']
				)
			);
		
		return $comment;
	}
	// END

	// -----------------------------
	//	 Add formatting to preview 
	// -----------------------------	
	
	function add_formatting_preview($row)
	{
		global $EXT, $IN, $TMPL;
		
		$comment_format = !$TMPL->fetch_param('format') ? '' : $TMPL->fetch_param('format');
		
		if ($comment_format != '')
		{
			$format = $comment_format;
		}		
		elseif ($this->settings['apply_all'] == 'yes')
		{
			$format = $this->settings['format'];		
		}
		else
		{
			$weblog_ids = explode('|', trim($this->settings['weblog_ids']));
			
			if (in_array($row['weblog_id'], $weblog_ids))
			{
				$format = $this->settings['format'];		
			}
			else
			{
				$format = $row['comment_text_formatting'];
			}
		}
		
		if ( ! class_exists('Typography'))
		{
			require PATH_CORE.'core.typography'.EXT;
		}
                
		$TYPE = new Typography(0);
		
		$comment = $EXT->last_call!=false ? $EXT->last_call : '';
		$comment .= $TYPE->parse_type(stripslashes($IN->GBL('comment', 'POST')), 
				array(
					'text_format'   => $format,
					'html_format'   => $row['comment_html_formatting'],
					'auto_links'    => $row['comment_auto_link_urls'],
					'allow_img_url' => $row['comment_allow_img_urls']
				)
			);
		
		return $comment;
	}
	// END

	// --------------------------------
	//  Activate Extension
	// --------------------------------
	
	function activate_extension()
	{
		global $DB;
		
		$default_settings = serialize(array('format'=>'textile','apply_all'=>'no','weblog_ids'=>''));
		
		$DB->query(	$DB->insert_string('exp_extensions',
									array('extension_id'	=> '',
									'class'			=> "Comment_text_format",
									'method'		=> "add_formatting",
									'hook'			=> "comment_entries_comment_format",
									'settings'		=> $default_settings,
									'priority'		=> 1,
									'version'		=> $this->version,
									'enabled'		=> "y"
									)
								)
		 					); 
		$DB->query(	$DB->insert_string('exp_extensions',
									array('extension_id'	=> '',
									'class'			=> "Comment_text_format",
									'method'		=> "add_formatting_preview",
									'hook'			=> "comment_preview_comment_format",
									'settings'		=> $default_settings,
									'priority'		=> 1,
									'version'		=> $this->version,
									'enabled'		=> "y"
									)
								)
		 					);		 					
	}
	// END

	// --------------------------------
	//  Update Extension
	// --------------------------------  
	
	function update_extension($current='')
	{
		global $DB;
		
		if ($current == '' OR $current == $this->version)
		{
			return FALSE;
		}
	
		if ($current < '1.1.1')
		{
			$DB->query("UPDATE exp_extensions SET method='add_formatting_preview' WHERE hook = 'comment_preview_comment_format' AND class = 'Comment_text_format'");				
		}
	
		$DB->query("UPDATE exp_extensions 
		SET version = '".$DB->escape_str($this->version)."' 
		WHERE class = 'Comment_text_format'");
	}
	// END
	
	
	// --------------------------------
	//  Disable Extension
	// --------------------------------	

	function disable_extension()
	{
		global $DB;
		
		$DB->query("DELETE FROM exp_extensions WHERE class = 'Comment_text_format'");
	}
	// END	
	
	// --------------------------------
	//  Settings
	// --------------------------------  
	
	function settings()
	{
		$settings = array();
		
		$settings['format'] = '';
		$settings['apply_all'] = array('s', array('yes'=>'Yes','no'=>'No'), 'yes');
		$settings['weblog_ids'] = '';

		return $settings;
	}
	// END	
}
// END Class

?>